# crystally

:mod:`crystally` is a python library to analyze and manipulate crystal structures. It is intended to be easy to learn and
understand. Have a look at the documentation to get started and an idea of the capabilities of the module.

Documentation: https://crystally.readthedocs.io/en/latest/
